@@ -39,7 +39,6 @@ __all__ = [
     'csr',
     'port',
     'lifecycle_states',
-    'set_com_port',
     'Chip',
     'Object'
 ]
@@ -49,10 +48,6 @@ UID = namedtuple("UID", "cim_id platform_id model_id rommask_id chip_type batch_
 _optiga_cddl = None
 
 
-def set_com_port(com_port):
-    _backend.set_com_port_config(com_port)
-
-
 def _lookup_optiga(api):
     api.exp_optiga_util_read_data.argtypes = c_ushort, c_ushort, POINTER(c_ubyte), POINTER(c_ushort)
     api.exp_optiga_util_read_data.restype = c_int
